@@ -8,6 +8,7 @@ import asyncio
 import platform
 
 from . import (
+    album,
     app,
     article,
     ass,
@@ -16,27 +17,31 @@ from . import (
     black_room,
     channel,
     cheese,
+    client,
     comment,
     dynamic,
+    emoji,
     favorite_list,
     game,
     homepage,
     interactive_video,
+    live_area,
     live,
-    login,
     login_func,
+    login,
+    manga,
+    note,
     rank,
     search,
+    session,
     settings,
     topic,
     user,
-    video,
-    emoji,
-    session,
-    vote,
     video_uploader,
+    video,
+    vote,
 )
-# TODO: 新增 manga 模块
+
 from .errors import (
     ApiException,
     ResponseCodeException,
@@ -68,60 +73,34 @@ if "windows" in platform.system().lower():
 
 # ALL
 __all__ = [
-    "ApiException",
-    "ArgsException",
+    "ApiException", "ArgsException",
     "Credential",
     "CredentialNoBiliJctException",
     "CredentialNoBuvid3Exception",
     "CredentialNoDedeUserIDException",
     "CredentialNoSessdataException",
-    "Danmaku",
-    "DanmakuClosedException",
-    "DmFontSize",
-    "DmMode",
+    "Danmaku", "DanmakuClosedException",
+    "DmFontSize", "DmMode",
     "DynamicExceedImagesException",
-    "HEADERS",
-    "LiveException",
-    "LoginError",
-    "NetworkException",
-    "Picture",
-    "ResourceType",
+    "HEADERS", "LiveException",
+    "LoginError", "NetworkException",
+    "Picture", "ResourceType",
     "ResponseCodeException",
     "ResponseException",
     "SpecialDanmaku",
     "VideoUploadException",
-    "aid2bvid",
-    "app",
-    "article",
-    "ass",
-    "audio",
-    "bangumi",
-    "black_room",
-    "bvid2aid",
-    "channel",
-    "cheese",
-    "comment",
-    "dynamic",
-    "emoji",
-    "favorite_list",
-    "game",
-    "get_real_url",
-    "get_session",
-    "homepage",
+    "aid2bvid", "album", "app",
+    "article", "ass", "asyncio",
+    "audio", "bangumi", "black_room",
+    "bvid2aid", "channel", "cheese",
+    "client", "comment", "dynamic",
+    "emoji", "favorite_list",
+    "game", "get_real_url",
+    "get_session", "homepage",
     "interactive_video",
-    "live",
-    "login",
-    "login_func",
-    "parse_link",
-    "rank",
-    "search",
-    "session",
-    "set_session",
-    "settings",
-    "sync",
-    "topic",
-    "user",
-    "video",
-    "video_uploader",
-    "vote",
+    "live", "live_area", "login", "login_func",
+    "manga", "note", "parse_link", "platform",
+    "rank", "search", "session", "set_session",
+    "settings", "sync", "topic", "user", "video",
+    "video_uploader", "vote",
 ]
