@@ -34,6 +34,9 @@ import re
 API = get_api("bangumi")
 
 
+episode_data_cache = {}
+
+
 class BangumiCommentOrder(Enum):
     """
     短评 / 长评 排序方式
@@ -265,6 +268,55 @@ class Bangumi:
             params = {"season_id": self.__ssid}
             return await request("GET", api["url"], params, credential=credential)
 
+    async def get_episodes(self) -> List["Episode"]:
+        """
+        获取番剧所有的剧集，自动生成类。
+        """
+        global episode_data_cache
+        episode_list = await self.get_episode_list()
+        if len(episode_list["main_section"]["episodes"]) == 0:
+            return []
+        first_epid = episode_list["main_section"]["episodes"][0]["id"]
+        async def get_episode_info(epid: int):
+            credential = self.credential if self.credential else Credential()
+            session = get_session()
+
+            try:
+                resp = await session.get(
+                    f"https://www.bilibili.com/bangumi/play/ep{epid}",
+                    cookies=credential.get_cookies(),
+                    headers={"User-Agent": "Mozilla/5.0"},
+                )
+            except Exception as e:
+                raise ResponseException(str(e))
+            else:
+                content = resp.text
+
+                pattern = re.compile(r"window.__INITIAL_STATE__=(\{.*?\});")
+                match = re.search(pattern, content)
+                if match is None:
+                    raise ApiException("未找到番剧信息")
+                try:
+                    content = json.loads(match.group(1))
+                except json.JSONDecodeError:
+                    raise ApiException("信息解析错误")
+
+                return content
+        bangumi_meta = await get_episode_info(first_epid)
+        bangumi_meta["media_id"] = self.get_media_id()
+
+        episodes = []
+        for ep in episode_list["main_section"]["episodes"]:
+            episode_data_cache[ep["id"]] = {
+                "bangumi_meta": bangumi_meta,
+                "bangumi_class": self,
+            }
+            episodes.append(Episode(
+                epid=ep["id"],
+                credential=self.credential
+            ))
+        return episodes
+
     async def get_stat(self) -> dict:
         """
         获取番剧播放量，追番等信息
@@ -315,6 +367,25 @@ async def set_follow(
     data = {"season_id": bangumi.get_season_id()}
     return await request("POST", api["url"], data=data, credential=credential)
 
+async def update_follow_status(
+    bangumi: Bangumi, status: int, credential: Union[Credential, None] = None
+) -> dict:
+    """
+    更新追番状态
+
+    Args:
+        bangumi    (Bangumi)                    : 番剧类
+        credential (Credential | None, optional): 凭据. Defaults to None.
+        status     (int)                        : 追番状态 1 想看 2 在看 3 已看
+    Returns:
+        dict: 调用 API 返回的结果
+    """
+    credential = credential if credential is not None else Credential()
+    credential.raise_for_no_sessdata()
+
+    api = API["operate"]["follow_status"]
+    data = {"season_id": bangumi.get_season_id(), "status": status}
+    return await request("POST", api["url"], data=data, credential=credential)
 
 class Episode(Video):
     """
@@ -332,19 +403,20 @@ class Episode(Video):
             epid       (int)                 : 番剧 epid
             credential (Credential, optional): 凭据. Defaults to None.
         """
+        global episode_data_cache
         self.credential = credential if credential else Credential()
         self.__epid = epid
-        try:
-            resp = httpx.get(
-                f"https://www.bilibili.com/bangumi/play/ep{self.__epid}",
-                cookies=self.credential.get_cookies(),
-                headers={"User-Agent": "Mozilla/5.0"},
-            )
-        except Exception as e:
-            raise ResponseException(str(e))
-        else:
-            content = resp.text
 
+        if not epid in episode_data_cache.keys():
+            try:
+                resp = httpx.get(
+                    f"https://www.bilibili.com/bangumi/play/ep{self.__epid}",
+                    cookies=self.credential.get_cookies(),
+                    headers={"User-Agent": "Mozilla/5.0"},
+                )
+            except Exception as e:
+                raise ResponseException(str(e))
+            content = resp.text
             pattern = re.compile(r"window.__INITIAL_STATE__=(\{.*?\});")
             match = re.search(pattern, content)
             if match is None:
@@ -353,9 +425,15 @@ class Episode(Video):
                 content = json.loads(match.group(1))
             except json.JSONDecodeError:
                 raise ApiException("信息解析错误")
-            else:
-                bvid = content["epInfo"]["bvid"]
-                self.bangumi = Bangumi(ssid=content["mediaInfo"]["season_id"])
+        else:
+            content = episode_data_cache[epid]["bangumi_meta"]
+
+        bvid = content["epInfo"]["bvid"]
+        if not epid in episode_data_cache.keys():
+            self.bangumi = Bangumi(ssid=content["mediaInfo"]["season_id"])
+        else:
+            self.bangumi = episode_data_cache[epid]["bangumi_class"]
+
         self.video_class = Video(bvid=bvid, credential=self.credential)
         super().__init__(bvid=bvid)
         self.set_aid = self.set_aid_e
@@ -389,7 +467,7 @@ class Episode(Video):
         Returns:
             Bangumi: 番剧类
         """
-        return self.bangumi
+        return self.bangumi # type: ignore
 
     def set_epid(self, epid: int) -> None:
         self.__init__(epid, self.credential)
