@@ -32,6 +32,9 @@ API = get_api("cheese")
 API_video = get_api("video")
 
 
+cheese_video_meta_cache = {}
+
+
 class CheeseList:
     """
     课程类
@@ -92,6 +95,19 @@ class CheeseList:
             "GET", api["url"], params=params, credential=self.credential
         )
 
+    async def get_list_raw(self):
+        """
+        获取教程所有视频 (返回原始数据)
+
+        Returns:
+            dict: 调用 API 返回的结果
+        """
+        api = API["info"]["list"]
+        params = {"season_id": self.__season_id, "pn": 1, "ps": 1000}
+        return await request(
+            "GET", api["url"], params=params, credential=self.credential
+        )
+
     async def get_list(self) -> List["CheeseVideo"]:
         """
         获取教程所有视频
@@ -99,6 +115,7 @@ class CheeseList:
         Returns:
             List[CheeseVideo]: 课程视频列表
         """
+        global cheese_video_meta_cache
         api = API["info"]["list"]
         params = {"season_id": self.__season_id, "pn": 1, "ps": 1000}
         lists = await request(
@@ -106,7 +123,9 @@ class CheeseList:
         )
         cheese_videos = []
         for c in lists["items"]:
-            cheese_videos.append(CheeseVideo(c["id"], self.credential, c))
+            c["ssid"] = self.get_season_id()
+            cheese_video_meta_cache[c["id"]] = c
+            cheese_videos.append(CheeseVideo(c["id"], self.credential))
         return cheese_videos
 
 
@@ -120,14 +139,19 @@ class CheeseVideo:
         cheese     (CheeseList): 所属的课程
     """
 
-    def __init__(self, epid, credential: Union[Credential, None] = None, meta=None):
+    def __init__(self, epid, credential: Union[Credential, None] = None):
         """
         Args:
             epid      (int)       : 单集 ep_id
             credential (Credential): 凭据类
         """
+        global cheese_video_meta_cache
         self.__epid = epid
-        self.cheese = CheeseList(ep_id=self.__epid)
+        meta = cheese_video_meta_cache.get(epid)
+        if meta == None:
+            self.cheese = CheeseList(ep_id=self.__epid)
+        else:
+            self.cheese = CheeseList(season_id=meta["ssid"])
         self.credential = credential if credential else Credential()
         if meta == None:
             api = API["info"]["meta"]
